# pokePalette
The pokePalette is a python library generate a color palette based on the colors of a chosen pokemon.  

![license](https://img.shields.io/github/license/MilanCalegari/pokePalette) ![stars](https://img.shields.io/github/stars/MilanCalegari/pokePalette?style=social)
____
## Requeriments:  
numpy  
opencv  
pokebase   
sklearn
____
## Usage:

```python
>>> import pokePalette
>>> palette = pokePalette.get_pokemon_palete("charizard")
>>> print(palette)
['#bd4831', '#0f4F64', '#ef8826', '#edD079']
```
